@@ -3,7 +3,6 @@ haplinSlide <- function(filename, data, pedIndex, markers = "ALL", winlength = 1
 ##
 ## RUN HAPLIN ON SLIDING WINDOWS
 ##
-## MERK: BRUKER "#i#" TIL AA KOMMENTERE VEKK DET SOM GIR ADVARSEL MED R CMD check, SIDEN DE RETTE PAKKENE IKKE ER INSTALLERT
 #
 ## SELECT PARALLEL MECHANISM (SOME MAY BE DISABLED)
 #.para <- "snow"
@@ -75,39 +74,46 @@ cat("\n")
 	}
 	#
 	##
-	# if(.info$filespecs$database){
-	# 	## HAPLIN DATABASE
-	# 	args_$markers <- .info$filespecs$markers[.slides[i,]]
-	# }else{
-		## FILE, DATA MATRIX, AND GWAA
-		args_$filename <- NULL
-		args_$markers <- .slides[i,]
-		args_$data <- .data.read
-		if(.is.gwaa & !.misspedIndex){
-			args_$pedIndex <- pedIndex
-		}
-	# }
+	## FILE, DATA MATRIX, AND GWAA
+	args_$filename <- NULL
+	args_$markers <- .slides[i,]
+	args_$data <- .data.read
+	if(.is.gwaa & !.misspedIndex){
+		args_$pedIndex <- pedIndex
+	}
+	#
+	## RUN HAPLIN
+	if(is.null(strata)){
+		.res <- try(do.call("haplin", args_), silent = T)
 		#
-		## RUN HAPLIN
-		if(is.null(strata)){
-			.res <- try(do.call("haplin", args_), silent = T)
-			#
-			## CHECK IF ERRORS
-			if(class(.res) == "try-error") cat("RUN FAILED\n")
-			else{
-				cat("done\n")
-				if(table.output) .res <- haptable(.res)
-			}		
+		## CHECK IF ERRORS
+		if(class(.res) == "try-error") cat("RUN FAILED\n")
+		else{
+			if(table.output) .res <- haptable(.res)
+			cat("done\n")
+		}		
+	}else{
+		.res <- try(do.call("haplinStrat", args_), silent = T)
+		## CHECK IF ERRORS
+		if(class(.res) == "try-error"){
+			cat("RUN FAILED\n")
 		}else{
-			.res <- try(do.call("haplinStrat", args_), silent = T)
-			## CHECK IF ERRORS
-			if(class(.res) == "try-error") cat("RUN FAILED\n")
-			else{
-				cat("done\n")
-				#.res <- posttest(.res)
-			}		
-		}
-		return(.res)
+			if(table.output){
+				.gxe.res <- try(gxe(.res))
+				if(class(.gxe.res) == "try-error"){
+					cat("RUN FAILED\n")
+					.res <- .gxe.res # somewhat ad hoc, but at least picks up the error message
+				}else{
+					# create haptables and join them
+					.gxe.res <- haptable(.gxe.res)
+					.res <- haptable(.res)
+					.res <- cbind(.res, .gxe.res)
+				}
+			}
+			cat("done\n")
+		}		
+	}
+	return(.res)
 }
 #
 ## DO THE RUN
@@ -123,13 +129,7 @@ if(!.run.para){
 	.errs <- sapply(.res.list, class) == "try-error"
 }else{
 	#
-	#
-	#	## INITIALIZE CPUS
-	if(.para == "snowfall"){
-		## SNOWFALL
-#i#		sfInit(parallel = T, slaveOutfile = slaveOutfile, cpus = cpus)
-#i#		on.exit(sfStop())
-	}
+	## INITIALIZE CPUS
 	if(.para == "parallel"){
 		## parallel
 		w <- parallel::makeCluster(spec = cpus, outfile = slaveOutfile)
@@ -155,37 +155,19 @@ if(!.run.para){
 			if(!missing(slaveOutfile)) sink()
 		})
 	}
-	if(.para == "doSMP"){
-		## doSMP BACKEND TO foreach
-#i#		w <- startWorkers(workerCount = cpus)
-#i#		on.exit(stopWorkers(w))
-#i#		registerDoSMP(w)
-	}
-	if(.para == "snow"){
-		## SNOW
-		# w <- makeCluster(cpus, type = type)
-#i#		w <- makeCluster(cpus)
-#i#		on.exit(stopCluster(w))
-	}
 	#
 	## RUN BY SPLITTING ON CPUS
 	if(!missing(slaveOutfile)) sink(file = slaveOutfile, append = T)
 		cat("\n--- Running haplinSlide using ", cpus, " cpu's ---\n\n", sep = "")
 	if(!missing(slaveOutfile)) sink()
-#i#	if(.para == "snowfall")	.res.list <- sfLapply(seq(length.out = .nres), .f.run)
 	if(.para == "parallel") .res.list <- parLapply(w, seq(length.out = .nres), .f.run)
-#i#	if(.para == "snow") .res.list <- parLapply(w, seq(length.out = .nres), .f.run)
-#i#	if(.para == "doSMP") .res.list <- foreach(i = seq(length.out = .nres)) %dopar% .f.run(i)
 	names(.res.list) <- .names
 	#
 	## CHECK FOR HAPLIN FAILURES
 	.ftest <- function(x){
 		return(identical(class(x), "try-error"))
 	}
-#i#	if(.para == "snowfall") .errs <- sfSapply(.res.list, .ftest)
 	if(.para == "parallel") .errs <- unlist(parLapply(w, .res.list, .ftest))
-#i#	if(.para == "snow") .errs <- parLapply(w, .res.list, class) == "try-error"
-#i#	if(.para == "doSMP") .errs <- foreach(i = seq(along = .res.list)) %dopar% class(.res.list[[i]]) == "try-error"
 }
 #
 ## GO THROUGH POSSIBLE ERRORS
@@ -205,7 +187,6 @@ if(!missing(slaveOutfile)) sink(file = slaveOutfile, append = T)
 if(!missing(slaveOutfile)) sink()
 #
 ## SET CLASS
-###if(!table.output) 
 class(.res.list) <- "haplinSlide"
 #
 ## RETURN RESULT LIST
